@@ -457,16 +457,19 @@ class Statement:
         new_data = indent(data, ' ' * lvl * self.indentation)
         return new_data
 
-    def get_display_method(self, lvl='info'):
-        lvl = str(lvl).strip().lower()
+    def get_display_method(self, level='info'):
+        level = str(level).strip().lower()
         chk_lst = ['debug', 'info', 'warning', 'error', 'fatal', 'critical']
-        lvl = lvl if lvl in chk_lst else 'info'
+        level = level if level in chk_lst else 'info'
         if self.is_logger:
             if self.is_ancestor_base_statement:
                 if self.is_ancestor_section_statement:
-                    return 'self.logger.%s' % lvl
+                    return 'self.logger.%s' % level
                 else:
-                    return 'cls.logger.%s' % lvl
+                    if self.is_unittest:
+                        return 'cls.logger.%s' % level
+                    else:
+                        return 'self.logger.%s' % level
         return 'print'
 
     def render_display_message(self, message):
@@ -1849,9 +1852,11 @@ class ScriptBuilder:
     def get_logger_function(self):
         func_text = dedent('''
             def get_logger(name='TATestScript'):
-                """This logger function has basic logging configure
-                ===================================================
-                Please replace your get logger function
+                """This function only creates logger instance with
+                basic logging configuration.
+                ==================================================
+                PLEASE UPDATE your get_logger function.
+                ==================================================
                 """
                 import logging
                 logging.basicConfig(
@@ -1862,7 +1867,7 @@ class ScriptBuilder:
                         logging.StreamHandler()
                     ]
                 )
-                logger = logging.get_logger(name)
+                logger = logging.getLogger(name)
                 return logger
         ''').strip()
 
@@ -1894,15 +1899,15 @@ class ScriptBuilder:
         if self.framework == FWTYPE.ROBOTFRAMEWORK:
             lst += [
                 '*** Settings ***',
-                'library         builtin',
-                'library         collections',
-                'library         describegetsystempoc',
-                'test setup      {}'.format(self.setup_statement.name),
-                'test teardown   {}'.format(self.teardown_statement.name),
+                'Library          BuiltIn',
+                'Library          Collections',
+                'Library          describegetsystempoc',
+                'Suite Setup      {}'.format(self.setup_statement.name),
+                'Suite Teardown   {}'.format(self.teardown_statement.name),
             ]
         else:
             cls_name = SCRIPTINFO.get_class_name()
-            inherit = '(unittest.Testcase)' if is_unittest else ''
+            inherit = '(unittest.TestCase)' if is_unittest else ''
             lst.append('import unittest' if is_unittest else '# import pytest')
             lst.append('import dgspoc as ta')
             lst.append('\n')
